/*
 * Copyright 1998 Vectaport Inc.
 * Copyright 1994,1995 Vectaport Inc., Cartoactive Systems
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

#ifndef mapeditor_h
#define mapeditor_h

#include <FrameUnidraw/frameeditor.h>
#include <MapUnidraw/mapkit.h>
#include <MapUnidraw/mapcmds.h>

extern "C" {
#include "projects.h"
}

class MapCovState;
class MapDatabase;
class MapDbComp;
class MapDbState;
class MapDbView;
class MapFClassState;
class MapLibState;
class MapSelectionState;
class MapViewState;
class ProjectionState;

class MapEditor : public FrameEditor {
public:
    MapEditor(OverlayComp*, OverlayKit* = MapKit::Instance());
    MapEditor(boolean initflag, OverlayKit* = MapKit::Instance());
    void Init(OverlayComp* = nil, 
	      const char* name = "MapEditor");
    void InitStateVars();
    boolean Initializing();
    void Initializing(boolean);
    virtual void OpenInit();
    PJ* GetProjection();
    void SetProjection(PJ* p);
    void SetProjectionLocal(PJ* p);
    void Reproject();

    MapDatabase* GetMapDatabase();
    void SetMapDatabase(MapDatabase* db);
    MapDbComp* GetMapDbComp();
    void SetMapDbComp(MapDbComp* dbcomp);
    MapDbView* GetMapDbView();
    GraphicComp* GetCameraComp() { return _camcomp; }
    void SetCameraComp(GraphicComp* comp) { _camcomp = comp; }

    virtual StateVar* GetState(const char*);
    virtual void InitCommands();
    virtual void AddCommands(ComTerp*);
    Graphic* MapGS() { return _mapgs; }
    void MapGS(Graphic* g) { _mapgs = g; }
    void AddPoint(float lat, float lon);

    MapViewState* GetMapViewState();
    void SetMapViewState(MapViewState*);
    boolean AdjustForGeo();

    ProjectionState* projstate() { return _projstate; }
    MapDbState* dbstate() { return _dbstate; }
    MapLibState* libstate() { return _libstate; }
    MapCovState* covstate() { return _covstate; }
    MapFClassState* fclassstate() { return _fclassstate; }
    MapSelectionState* selstate() { return _selstate; }

    virtual void UpdateLayerMenu();
    virtual void UpdateLibraryMenu();

    GSEditor* gseditor() { return ((MapKit*)_overlay_kit)->gseditor(); }
    ThemeChooser* thchooser() { return ((MapKit*)_overlay_kit)->thchooser(); }
    NameView* ProjNameView() { return ((MapKit*)_overlay_kit)->ProjNameView(); }

protected:
    virtual void InitMapComp();
    Interactor* Interior();
protected:
    boolean _init;
    PJ* _projection;
    MapDatabase* _mapdb;
    MapViewState* _mapview;
    Graphic* _mapgs;
    MapDbComp* _mapcomp;
    GraphicComp* _camcomp;

    ProjectionState* _projstate;
    MapDbState* _dbstate;
    MapLibState* _libstate;
    MapCovState* _covstate;
    MapFClassState* _fclassstate;
    MapSelectionState* _selstate;

friend MapKit;
};

#endif
